# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/user_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/cost_analysis/v1/user_dashboard.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"1\n\x13UserDashboardPeriod\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\"\xb0\x03\n\x1a\x43reateUserDashboardRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x02 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Y\n\x0bperiod_type\x18\x05 \x01(\x0e\x32\x44.spaceone.api.cost_analysis.v1.CreateUserDashboardRequest.PeriodType\x12\x42\n\x06period\x18\x06 \x01(\x0b\x32\x32.spaceone.api.cost_analysis.v1.UserDashboardPeriod\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xcb\x03\n\x1aUpdateUserDashboardRequest\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Y\n\x0bperiod_type\x18\x06 \x01(\x0e\x32\x44.spaceone.api.cost_analysis.v1.UpdateUserDashboardRequest.PeriodType\x12\x42\n\x06period\x18\x07 \x01(\x0b\x32\x32.spaceone.api.cost_analysis.v1.UserDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"D\n\x14UserDashboardRequest\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"U\n\x17GetUserDashboardRequest\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8d\x02\n\x12UserDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11user_dashboard_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12Q\n\x0bperiod_type\x18\x04 \x01(\x0e\x32<.spaceone.api.cost_analysis.v1.UserDashboardQuery.PeriodType\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xf2\x03\n\x11UserDashboardInfo\x12\x19\n\x11user_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12P\n\x0bperiod_type\x18\x06 \x01(\x0e\x32;.spaceone.api.cost_analysis.v1.UserDashboardInfo.PeriodType\x12\x42\n\x06period\x18\x07 \x01(\x0b\x32\x32.spaceone.api.cost_analysis.v1.UserDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"l\n\x12UserDashboardsInfo\x12\x41\n\x07results\x18\x01 \x03(\x0b\x32\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16UserDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xfd\x07\n\rUserDashboard\x12\xa0\x01\n\x06\x63reate\x12\x39.spaceone.api.cost_analysis.v1.CreateUserDashboardRequest\x1a\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\")\x82\xd3\xe4\x93\x02#\"!/cost-analysis/v1/user-dashboards\x12\xb3\x01\n\x06update\x12\x39.spaceone.api.cost_analysis.v1.UpdateUserDashboardRequest\x1a\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\"<\x82\xd3\xe4\x93\x02\x36\x1a\x34/cost-analysis/v1/user-dashboard/{user_dashboard_id}\x12\x93\x01\n\x06\x64\x65lete\x12\x33.spaceone.api.cost_analysis.v1.UserDashboardRequest\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36*4/cost-analysis/v1/user-dashboard/{user_dashboard_id}\x12\xad\x01\n\x03get\x12\x36.spaceone.api.cost_analysis.v1.GetUserDashboardRequest\x1a\x30.spaceone.api.cost_analysis.v1.UserDashboardInfo\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cost-analysis/v1/user-dashboard/{user_dashboard_id}\x12\xc3\x01\n\x04list\x12\x31.spaceone.api.cost_analysis.v1.UserDashboardQuery\x1a\x31.spaceone.api.cost_analysis.v1.UserDashboardsInfo\"U\x82\xd3\xe4\x93\x02O\x12!/cost-analysis/v1/user-dashboardsZ*\"(/cost-analysis/v1/user-dashboards/search\x12\x86\x01\n\x04stat\x12\x35.spaceone.api.cost_analysis.v1.UserDashboardStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/cost-analysis/v1/user-dashboards/statb\x06proto3')



_USERDASHBOARDPERIOD = DESCRIPTOR.message_types_by_name['UserDashboardPeriod']
_CREATEUSERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreateUserDashboardRequest']
_UPDATEUSERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserDashboardRequest']
_USERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UserDashboardRequest']
_GETUSERDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetUserDashboardRequest']
_USERDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['UserDashboardQuery']
_USERDASHBOARDINFO = DESCRIPTOR.message_types_by_name['UserDashboardInfo']
_USERDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['UserDashboardsInfo']
_USERDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['UserDashboardStatQuery']
_CREATEUSERDASHBOARDREQUEST_PERIODTYPE = _CREATEUSERDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_UPDATEUSERDASHBOARDREQUEST_PERIODTYPE = _UPDATEUSERDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_USERDASHBOARDQUERY_PERIODTYPE = _USERDASHBOARDQUERY.enum_types_by_name['PeriodType']
_USERDASHBOARDINFO_PERIODTYPE = _USERDASHBOARDINFO.enum_types_by_name['PeriodType']
UserDashboardPeriod = _reflection.GeneratedProtocolMessageType('UserDashboardPeriod', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDPERIOD,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardPeriod)
  })
_sym_db.RegisterMessage(UserDashboardPeriod)

CreateUserDashboardRequest = _reflection.GeneratedProtocolMessageType('CreateUserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateUserDashboardRequest)
  })
_sym_db.RegisterMessage(CreateUserDashboardRequest)

UpdateUserDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdateUserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateUserDashboardRequest)
  })
_sym_db.RegisterMessage(UpdateUserDashboardRequest)

UserDashboardRequest = _reflection.GeneratedProtocolMessageType('UserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardRequest)
  })
_sym_db.RegisterMessage(UserDashboardRequest)

GetUserDashboardRequest = _reflection.GeneratedProtocolMessageType('GetUserDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetUserDashboardRequest)
  })
_sym_db.RegisterMessage(GetUserDashboardRequest)

UserDashboardQuery = _reflection.GeneratedProtocolMessageType('UserDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardQuery)
  })
_sym_db.RegisterMessage(UserDashboardQuery)

UserDashboardInfo = _reflection.GeneratedProtocolMessageType('UserDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardInfo)
  })
_sym_db.RegisterMessage(UserDashboardInfo)

UserDashboardsInfo = _reflection.GeneratedProtocolMessageType('UserDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardsInfo)
  })
_sym_db.RegisterMessage(UserDashboardsInfo)

UserDashboardStatQuery = _reflection.GeneratedProtocolMessageType('UserDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.user_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UserDashboardStatQuery)
  })
_sym_db.RegisterMessage(UserDashboardStatQuery)

_USERDASHBOARD = DESCRIPTOR.services_by_name['UserDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERDASHBOARD.methods_by_name['create']._options = None
  _USERDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/cost-analysis/v1/user-dashboards'
  _USERDASHBOARD.methods_by_name['update']._options = None
  _USERDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\0026\0324/cost-analysis/v1/user-dashboard/{user_dashboard_id}'
  _USERDASHBOARD.methods_by_name['delete']._options = None
  _USERDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0026*4/cost-analysis/v1/user-dashboard/{user_dashboard_id}'
  _USERDASHBOARD.methods_by_name['get']._options = None
  _USERDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\0026\0224/cost-analysis/v1/user-dashboard/{user_dashboard_id}'
  _USERDASHBOARD.methods_by_name['list']._options = None
  _USERDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/cost-analysis/v1/user-dashboardsZ*\"(/cost-analysis/v1/user-dashboards/search'
  _USERDASHBOARD.methods_by_name['stat']._options = None
  _USERDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/cost-analysis/v1/user-dashboards/stat'
  _USERDASHBOARDPERIOD._serialized_start=208
  _USERDASHBOARDPERIOD._serialized_end=257
  _CREATEUSERDASHBOARDREQUEST._serialized_start=260
  _CREATEUSERDASHBOARDREQUEST._serialized_end=692
  _CREATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_start=649
  _CREATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_end=692
  _UPDATEUSERDASHBOARDREQUEST._serialized_start=695
  _UPDATEUSERDASHBOARDREQUEST._serialized_end=1154
  _UPDATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_start=649
  _UPDATEUSERDASHBOARDREQUEST_PERIODTYPE._serialized_end=692
  _USERDASHBOARDREQUEST._serialized_start=1156
  _USERDASHBOARDREQUEST._serialized_end=1224
  _GETUSERDASHBOARDREQUEST._serialized_start=1226
  _GETUSERDASHBOARDREQUEST._serialized_end=1311
  _USERDASHBOARDQUERY._serialized_start=1314
  _USERDASHBOARDQUERY._serialized_end=1583
  _USERDASHBOARDQUERY_PERIODTYPE._serialized_start=649
  _USERDASHBOARDQUERY_PERIODTYPE._serialized_end=692
  _USERDASHBOARDINFO._serialized_start=1586
  _USERDASHBOARDINFO._serialized_end=2084
  _USERDASHBOARDINFO_PERIODTYPE._serialized_start=649
  _USERDASHBOARDINFO_PERIODTYPE._serialized_end=692
  _USERDASHBOARDSINFO._serialized_start=2086
  _USERDASHBOARDSINFO._serialized_end=2194
  _USERDASHBOARDSTATQUERY._serialized_start=2196
  _USERDASHBOARDSTATQUERY._serialized_end=2293
  _USERDASHBOARD._serialized_start=2296
  _USERDASHBOARD._serialized_end=3317
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/notification/v1/protocol.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x99\x02\n\rPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x05 \x01(\t\x12M\n\x0cupgrade_mode\x18\x06 \x01(\x0e\x32\x37.spaceone.api.notification.v1.PluginRequest.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\x93\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12J\n\x0cupgrade_mode\x18\x07 \x01(\x0e\x32\x34.spaceone.api.notification.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\xa1\x01\n\x15\x43reateProtocolRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x0bplugin_info\x18\x02 \x01(\x0b\x32+.spaceone.api.notification.v1.PluginRequest\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"t\n\x15UpdateProtocolRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x80\x01\n\x1bUpdateProtocolPluginRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"9\n\x0fProtocolRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"J\n\x12GetProtocolRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x86\x03\n\rProtocolQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bprotocol_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x05state\x18\x04 \x01(\x0e\x32\x39.spaceone.api.notification.v1.ProtocolQuery.ProtocolState\x12O\n\rprotocol_type\x18\x05 \x01(\x0e\x32\x38.spaceone.api.notification.v1.ProtocolQuery.ProtocolType\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"4\n\rProtocolState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"B\n\x0cProtocolType\x12\x16\n\x12PROTOCOL_TYPE_NONE\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\x95\x04\n\x0cProtocolInfo\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12G\n\x05state\x18\x03 \x01(\x0e\x32\x38.spaceone.api.notification.v1.ProtocolInfo.ProtocolState\x12N\n\rprotocol_type\x18\x04 \x01(\x0e\x32\x37.spaceone.api.notification.v1.ProtocolInfo.ProtocolType\x12\x15\n\rresource_type\x18\x05 \x01(\t\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12=\n\x0bplugin_info\x18\x07 \x01(\x0b\x32(.spaceone.api.notification.v1.PluginInfo\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"4\n\rProtocolState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"B\n\x0cProtocolType\x12\x16\n\x12PROTOCOL_TYPE_NONE\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"a\n\rProtocolsInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.notification.v1.ProtocolInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\\\n\x11ProtocolStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xe7\n\n\x08Protocol\x12\x8d\x01\n\x06\x63reate\x12\x33.spaceone.api.notification.v1.CreateProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/notification/v1/protocols\x12\x9a\x01\n\x06update\x12\x33.spaceone.api.notification.v1.UpdateProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"/\x82\xd3\xe4\x93\x02)\x1a\'/notification/v1/protocol/{protocol_id}\x12\xae\x01\n\rupdate_plugin\x12\x39.spaceone.api.notification.v1.UpdateProtocolPluginRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./notification/v1/protocol/{protocol_id}/plugin\x12\x9b\x01\n\x06\x65nable\x12-.spaceone.api.notification.v1.ProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./notification/v1/protocol/{protocol_id}/enable\x12\x9d\x01\n\x07\x64isable\x12-.spaceone.api.notification.v1.ProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//notification/v1/protocol/{protocol_id}/disable\x12\x80\x01\n\x06\x64\x65lete\x12-.spaceone.api.notification.v1.ProtocolRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)*\'/notification/v1/protocol/{protocol_id}\x12\x94\x01\n\x03get\x12\x30.spaceone.api.notification.v1.GetProtocolRequest\x1a*.spaceone.api.notification.v1.ProtocolInfo\"/\x82\xd3\xe4\x93\x02)\x12\'/notification/v1/protocol/{protocol_id}\x12\xa9\x01\n\x04list\x12+.spaceone.api.notification.v1.ProtocolQuery\x1a+.spaceone.api.notification.v1.ProtocolsInfo\"G\x82\xd3\xe4\x93\x02\x41\x12\x1a/notification/v1/protocolsZ#\"!/notification/v1/protocols/search\x12y\n\x04stat\x12/.spaceone.api.notification.v1.ProtocolStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/notification/v1/protocols/statb\x06proto3')



_PLUGINREQUEST = DESCRIPTOR.message_types_by_name['PluginRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_CREATEPROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['CreateProtocolRequest']
_UPDATEPROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['UpdateProtocolRequest']
_UPDATEPROTOCOLPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateProtocolPluginRequest']
_PROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['ProtocolRequest']
_GETPROTOCOLREQUEST = DESCRIPTOR.message_types_by_name['GetProtocolRequest']
_PROTOCOLQUERY = DESCRIPTOR.message_types_by_name['ProtocolQuery']
_PROTOCOLINFO = DESCRIPTOR.message_types_by_name['ProtocolInfo']
_PROTOCOLSINFO = DESCRIPTOR.message_types_by_name['ProtocolsInfo']
_PROTOCOLSTATQUERY = DESCRIPTOR.message_types_by_name['ProtocolStatQuery']
_PLUGINREQUEST_UPGRADEMODE = _PLUGINREQUEST.enum_types_by_name['UpgradeMode']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_PROTOCOLQUERY_PROTOCOLSTATE = _PROTOCOLQUERY.enum_types_by_name['ProtocolState']
_PROTOCOLQUERY_PROTOCOLTYPE = _PROTOCOLQUERY.enum_types_by_name['ProtocolType']
_PROTOCOLINFO_PROTOCOLSTATE = _PROTOCOLINFO.enum_types_by_name['ProtocolState']
_PROTOCOLINFO_PROTOCOLTYPE = _PROTOCOLINFO.enum_types_by_name['ProtocolType']
PluginRequest = _reflection.GeneratedProtocolMessageType('PluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.PluginRequest)
  })
_sym_db.RegisterMessage(PluginRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

CreateProtocolRequest = _reflection.GeneratedProtocolMessageType('CreateProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateProtocolRequest)
  })
_sym_db.RegisterMessage(CreateProtocolRequest)

UpdateProtocolRequest = _reflection.GeneratedProtocolMessageType('UpdateProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProtocolRequest)
  })
_sym_db.RegisterMessage(UpdateProtocolRequest)

UpdateProtocolPluginRequest = _reflection.GeneratedProtocolMessageType('UpdateProtocolPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROTOCOLPLUGINREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateProtocolPluginRequest)
  })
_sym_db.RegisterMessage(UpdateProtocolPluginRequest)

ProtocolRequest = _reflection.GeneratedProtocolMessageType('ProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolRequest)
  })
_sym_db.RegisterMessage(ProtocolRequest)

GetProtocolRequest = _reflection.GeneratedProtocolMessageType('GetProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROTOCOLREQUEST,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetProtocolRequest)
  })
_sym_db.RegisterMessage(GetProtocolRequest)

ProtocolQuery = _reflection.GeneratedProtocolMessageType('ProtocolQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLQUERY,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolQuery)
  })
_sym_db.RegisterMessage(ProtocolQuery)

ProtocolInfo = _reflection.GeneratedProtocolMessageType('ProtocolInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLINFO,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolInfo)
  })
_sym_db.RegisterMessage(ProtocolInfo)

ProtocolsInfo = _reflection.GeneratedProtocolMessageType('ProtocolsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLSINFO,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolsInfo)
  })
_sym_db.RegisterMessage(ProtocolsInfo)

ProtocolStatQuery = _reflection.GeneratedProtocolMessageType('ProtocolStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.protocol_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.ProtocolStatQuery)
  })
_sym_db.RegisterMessage(ProtocolStatQuery)

_PROTOCOL = DESCRIPTOR.services_by_name['Protocol']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROTOCOL.methods_by_name['create']._options = None
  _PROTOCOL.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\034\"\032/notification/v1/protocols'
  _PROTOCOL.methods_by_name['update']._options = None
  _PROTOCOL.methods_by_name['update']._serialized_options = b'\202\323\344\223\002)\032\'/notification/v1/protocol/{protocol_id}'
  _PROTOCOL.methods_by_name['update_plugin']._options = None
  _PROTOCOL.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0020\032./notification/v1/protocol/{protocol_id}/plugin'
  _PROTOCOL.methods_by_name['enable']._options = None
  _PROTOCOL.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0020\032./notification/v1/protocol/{protocol_id}/enable'
  _PROTOCOL.methods_by_name['disable']._options = None
  _PROTOCOL.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0021\032//notification/v1/protocol/{protocol_id}/disable'
  _PROTOCOL.methods_by_name['delete']._options = None
  _PROTOCOL.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002)*\'/notification/v1/protocol/{protocol_id}'
  _PROTOCOL.methods_by_name['get']._options = None
  _PROTOCOL.methods_by_name['get']._serialized_options = b'\202\323\344\223\002)\022\'/notification/v1/protocol/{protocol_id}'
  _PROTOCOL.methods_by_name['list']._options = None
  _PROTOCOL.methods_by_name['list']._serialized_options = b'\202\323\344\223\002A\022\032/notification/v1/protocolsZ#\"!/notification/v1/protocols/search'
  _PROTOCOL.methods_by_name['stat']._options = None
  _PROTOCOL.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002!\"\037/notification/v1/protocols/stat'
  _PLUGINREQUEST._serialized_start=201
  _PLUGINREQUEST._serialized_end=482
  _PLUGINREQUEST_UPGRADEMODE._serialized_start=437
  _PLUGINREQUEST_UPGRADEMODE._serialized_end=482
  _PLUGININFO._serialized_start=485
  _PLUGININFO._serialized_end=760
  _PLUGININFO_UPGRADEMODE._serialized_start=437
  _PLUGININFO_UPGRADEMODE._serialized_end=482
  _CREATEPROTOCOLREQUEST._serialized_start=763
  _CREATEPROTOCOLREQUEST._serialized_end=924
  _UPDATEPROTOCOLREQUEST._serialized_start=926
  _UPDATEPROTOCOLREQUEST._serialized_end=1042
  _UPDATEPROTOCOLPLUGINREQUEST._serialized_start=1045
  _UPDATEPROTOCOLPLUGINREQUEST._serialized_end=1173
  _PROTOCOLREQUEST._serialized_start=1175
  _PROTOCOLREQUEST._serialized_end=1232
  _GETPROTOCOLREQUEST._serialized_start=1234
  _GETPROTOCOLREQUEST._serialized_end=1308
  _PROTOCOLQUERY._serialized_start=1311
  _PROTOCOLQUERY._serialized_end=1701
  _PROTOCOLQUERY_PROTOCOLSTATE._serialized_start=1581
  _PROTOCOLQUERY_PROTOCOLSTATE._serialized_end=1633
  _PROTOCOLQUERY_PROTOCOLTYPE._serialized_start=1635
  _PROTOCOLQUERY_PROTOCOLTYPE._serialized_end=1701
  _PROTOCOLINFO._serialized_start=1704
  _PROTOCOLINFO._serialized_end=2237
  _PROTOCOLINFO_PROTOCOLSTATE._serialized_start=1581
  _PROTOCOLINFO_PROTOCOLSTATE._serialized_end=1633
  _PROTOCOLINFO_PROTOCOLTYPE._serialized_start=1635
  _PROTOCOLINFO_PROTOCOLTYPE._serialized_end=1701
  _PROTOCOLSINFO._serialized_start=2239
  _PROTOCOLSINFO._serialized_end=2336
  _PROTOCOLSTATQUERY._serialized_start=2338
  _PROTOCOLSTATQUERY._serialized_end=2430
  _PROTOCOL._serialized_start=2433
  _PROTOCOL._serialized_end=3816
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import public_dashboard_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2


class PublicDashboardStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.PublicDashboard/create',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.CreatePublicDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.PublicDashboard/update',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.UpdatePublicDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.PublicDashboard/delete',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.PublicDashboard/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.GetPublicDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.PublicDashboard/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.PublicDashboard/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class PublicDashboardServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new PublicDashboard. This method is used for creating the default dashboard . `Admin` type Users can use the method to add a new dashboard with customized widgets.
        request_example: >-
        {
        "name": "Untitled Dashboard",
        "custom_layouts": [
        [
        {
        "name": "AWS Data-Transfer Cost Trend",
        "widget_id": "linegraph-lg-02",
        "options": {
        "chart_type": "LINE",
        "layout": 100.0,
        "chart_img": "AWS_Data-Transfer_Cost_Trend",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC"
        }
        }
        ],
        [
        {
        "name": "AWS Data-Transfer by Region",
        "widget_id": "map-lg-02",
        "options": {
        "chart_type": "MAP", "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "chart_img": "AWS_Data-Transfer_By_Region"
        }
        }
        ],
        [
        {
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03",
        "options": {
        "group_by": "project_id",
        "chart_img": "AWS_CloudFront_Cost",
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "chart_type": "STACKED_COLUMN"
        }
        }
        ]
        ],
        "default_filter": {},
        "period_type": "AUTO"
        }
        response_example: >-
        {
        "public_dashboard_id": "pub-dash-80092b5ef658",
        "name": "Untitled Dashboard",
        "custom_layouts": [
        [
        {
        "options": {
        "layout": 100.0,
        "chart_type": "LINE",
        "chart_img": "AWS_Data-Transfer_Cost_Trend",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC"
        },
        "widget_id": "linegraph-lg-02",
        "name": "AWS Data-Transfer Cost Trend"
        }
        ],
        [
        {
        "widget_id": "map-lg-02",
        "name": "AWS Data-Transfer by Region",
        "options": {
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "chart_img": "AWS_Data-Transfer_By_Region",
        "chart_type": "MAP"
        }
        }
        ],
        [
        {
        "options": {
        "chart_type": "STACKED_COLUMN",
        "chart_img": "AWS_CloudFront_Cost",
        "layout": 100.0,
        "group_by": "project_id",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC"
        },
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03"
        }
        ]
        ],
        "default_filter": {},
        "period_type": "AUTO",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T05:42:01.412Z",
        "updated_at": "2022-07-19T05:42:01.412Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific PublicDashboard. Changes the widgets of the PublicDashboard with default widgets and customized widgets. Only `Admin` type Users can use the method.
        request_example: >-
        {
        "public_dashboard_id": "pub-dash-80092b5ef658",
        "name": "Untitled Dashboard2",
        "custom_layouts": [
        [
        {
        "widget_id": "linegraph-lg-02",
        "name": "AWS Data-Transfer Cost Trend",
        "options": {
        "chart_type": "LINE",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC",
        "chart_img": "AWS_Data-Transfer_Cost_Trend",
        "layout": 100.0
        }
        }
        ],
        [
        {
        "name": "AWS Data-Transfer by Region",
        "widget_id": "map-lg-02",
        "options": {
        "chart_type": "MAP",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "layout": 100.0,
        "chart_img": "AWS_Data-Transfer_By_Region"
        }
        }
        ],
        [
        {
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03",
        "options": {
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "group_by": "project_id",
        "chart_type": "STACKED_COLUMN",
        "chart_img": "AWS_CloudFront_Cost"
        }
        }
        ]
        ]
        }
        response_example: >-
        {
        "public_dashboard_id": "pub-dash-80092b5ef658",
        "name": "Untitled Dashboard2",
        "custom_layouts": [
        [
        {
        "options": {
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC",
        "layout": 100.0,
        "chart_type": "LINE",
        "chart_img": "AWS_Data-Transfer_Cost_Trend"
        },
        "name": "AWS Data-Transfer Cost Trend",
        "widget_id": "linegraph-lg-02"
        }
        ],
        [
        {
        "options": {
        "chart_type": "MAP",
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "chart_img": "AWS_Data-Transfer_By_Region"
        },
        "widget_id": "map-lg-02",
        "name": "AWS Data-Transfer by Region"
        }
        ],
        [
        {
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03",
        "options": {
        "chart_img": "AWS_CloudFront_Cost",
        "chart_type": "STACKED_COLUMN",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "layout": 100.0,
        "group_by": "project_id"
        }
        }
        ]
        ],
        "default_filter": {},
        "period_type": "AUTO",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T05:42:01.412Z",
        "updated_at": "2022-07-19T05:42:01.412Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific PublicDashboard. You must specify the `public_dashboard_id` of the PublicDashboard to delete.
        request_example: >-
        {
        "public_dashboard_id": "pub-dash-579b38f00dcf"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific PublicDashboard. Prints detailed information about the PublicDashboard, including `custom_layouts` and `period_type`.
        request_example: >-
        {
        "public_dashboard_id": "pub-dash-579b38f00dcf"
        }
        response_example: >-
        {
        "public_dashboard_id": "pub-dash-579b38f00dcf",
        "name": "CDN & Traffic Cost",
        "custom_layouts": [
        [
        {
        "name": "AWS Data-Transfer Cost Trend",
        "widget_id": "linegraph-lg-02",
        "options": {
        "chart_type": "LINE",
        "layout": 100.0
        }
        }
        ],
        [
        {
        "options": {
        "layout": 100.0,
        "group_by": "project_id",
        "chart_type": "STACKED_COLUMN"
        },
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03"
        }
        ],
        [
        {
        "widget_id": "map-lg-02",
        "name": "AWS Data-Transfer by Region",
        "options": {
        "layout": 100.0,
        "chart_type": "MAP"
        }
        }
        ]
        ],
        "default_filter": {
        "project_group_id": [],
        "service_account_id": [],
        "project_id": [],
        "provider": [
        "google_cloud",
        "azure",
        "aws_china",
        "aws"
        ]
        },
        "period_type": "AUTO",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-07T02:31:28.197Z",
        "updated_at": "2022-04-07T02:31:28.197Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all PublicDashboards. You can use a query to get a filtered list of PublicDashboards.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "public_dashboard_id": "pub-dash-579b38f00dcf",
        "name": "CDN & Traffic Cost",
        "custom_layouts": [
        [
        {
        "widget_id": "linegraph-lg-02",
        "name": "AWS Data-Transfer Cost Trend",
        "options": {
        "chart_type": "LINE",
        "layout": 100.0
        }
        }
        ],
        [
        {
        "name": "AWS CloudFront Cost by Project",
        "options": {
        "group_by": "project_id",
        "chart_type": "STACKED_COLUMN",
        "layout": 100.0
        },
        "widget_id": "stackedcol-lg-03"
        }
        ],
        [
        {
        "options": {
        "layout": 100.0,
        "chart_type": "MAP"
        },
        "widget_id": "map-lg-02",
        "name": "AWS Data-Transfer by Region"
        }
        ]
        ],
        "default_filter": {
        "project_id": [],
        "service_account_id": [],
        "project_group_id": [],
        "provider": [
        "google_cloud",
        "azure",
        "aws_china",
        "aws"
        ]
        },
        "period_type": "AUTO",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-07T02:31:28.197Z",
        "updated_at": "2022-04-07T02:31:28.197Z"
        },
        {
        "public_dashboard_id": "pub-dash-fc83ed9bc825",
        "name": "Monthly Cost Summary",
        "custom_layouts": [
        [
        {
        "options": {
        "layout": 33.0,
        "chart_type": "CARD"
        },
        "widget_id": "card-sm-01",
        "name": "Month-to-Date Spend"
        },
        {
        "name": "Last Month Total Spend",
        "widget_id": "card-sm-02",
        "options": {
        "layout": 33.0,
        "chart_type": "CARD"
        }
        },
        {
        "widget_id": "card-sm-03",
        "name": "Budget Usage",
        "options": {
        "chart_type": "CARD",
        "layout": 33.0
        }
        }
        ],
        [
        {
        "name": "Cost By Project",
        "widget_id": "treemap-lg-01",
        "options": {
        "group_by": "project_id",
        "layout": 100.0,
        "chart_type": "TREEMAP"
        }
        }
        ],
        [
        {
        "name": "Cost Trend By Project",
        "widget_id": "linegraph-lg-01",
        "options": {
        "layout": 100.0,
        "group_by": "provider",
        "chart_type": "LINE"
        }
        }
        ],
        [
        {
        "options": {
        "layout": 100.0,
        "chart_type": "STACKED_COLUMN",
        "group_by": "product"
        },
        "widget_id": "stackedcol-lg-01",
        "name": "Cost Trend By Product"
        }
        ],
        [
        {
        "name": "Cost By Provider",
        "options": {
        "layout": 50.0,
        "group_by": "provider",
        "chart_type": "STACKED_COLUMN"
        },
        "widget_id": "donut-md-01"
        },
        {
        "widget_id": "waffle-md-01",
        "name": "Budget Status",
        "options": {
        "layout": 50.0,
        "chart_type": "WAFFLE"
        }
        }
        ],
        [
        {
        "options": {
        "chart_type": "MAP",
        "layout": 100.0
        },
        "widget_id": "map-lg-01",
        "name": "Cost By Region"
        }
        ]
        ],
        "default_filter": {
        "provider": []
        },
        "period_type": "AUTO",
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-29T05:22:41.283Z",
        "updated_at": "2022-03-29T05:22:41.283Z"
        }
        ],
        "total_count": 3
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PublicDashboardServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.CreatePublicDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.UpdatePublicDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.GetPublicDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.PublicDashboard', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PublicDashboard(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.PublicDashboard/create',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.CreatePublicDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.PublicDashboard/update',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.UpdatePublicDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.PublicDashboard/delete',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.PublicDashboard/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.GetPublicDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.PublicDashboard/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.PublicDashboard/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_public__dashboard__pb2.PublicDashboardStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import cost_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2


class CostStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/create',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CreateCostRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/delete',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.GetCostRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostsInfo.FromString,
                )
        self.analyze = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/analyze',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.invoices = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/invoices',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.invoice = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.Cost/invoice',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class CostServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Cost. When creating a Cost, if the parameter `provider` is not entered, the default value of the parameter will be the provider information of the DataSource which collected the raw data of the Cost from the provider. The parameter `billed_at` is the data of when the cost is billed. While the DataSource collects the cost data, if the `billed_at` data does not exist, the value will be replaced with the `created_at` data indicating when the Cost is created. If the cost data collected is based on USD, the Cost is created without the currency exchange.
        request_example: >-
        {
        "original_cost": 4.50528e-08,
        "original_currency": "USD",
        "usd_cost": 4.50528e-08,
        "usage_quantity": 4.11e-07,
        "provider": "aws",
        "region_code": "ap-northeast-1",
        "product": "AWSDataTransfer",
        "account": "722069360300",
        "usage_type": "data-transfer.out",
        "additional_info": {
        "raw_usage_type": "APN1-DataTransfer-Out-Bytes"
        },
        "data_source_id": "ds-fcba92ca73b1"
        }
        response_example: >-
        {
        "cost_id": "cost-c5aae7712ec9",
        "usd_cost": 4.50528e-08,
        "original_currency": "USD",
        "original_cost": 4.50528e-08,
        "usage_quantity": 4.11e-07,
        "provider": "aws",
        "region_code": "ap-northeast-1",
        "product": "AWSDataTransfer",
        "account": "722069360300",
        "usage_type": "data-transfer.out",
        "tags": {},
        "additional_info": {
        "raw_usage_type": "APN1-DataTransfer-Out-Bytes"
        },
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "billed_at": "2022-07-19T09:44:27.326Z",
        "created_at": "2022-07-19T09:44:27.373Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Cost. You must specify the `cost_id` of the Cost to delete.
        request_example: >-
        {
        "cost_id": "cost-2ad052ed03d7"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Cost. Prints detailed information about the Cost, including  `region_code` and `account`.
        request_example: >-
        {
        "cost_id": "cost-2ad052ed03d7"
        }
        response_example: >-
        {
        "cost_id": "cost-2ad052ed03d7",
        "usd_cost": 4.50528e-08,
        "original_currency": "USD",
        "original_cost": 4.50528e-08,
        "usage_quantity": 4.11e-07,
        "provider": "aws",
        "region_code": "ap-northeast-1",
        "product": "AWSDataTransfer",
        "account": "722069360300",
        "usage_type": "data-transfer.out",
        "tags": {},
        "additional_info": {
        "raw_usage_type": "APN1-DataTransfer-Out-Bytes"
        },
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "billed_at": "2021-01-01T00:00:00.000Z",
        "created_at": "2022-04-06T13:49:39.669Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Costs. You can use a query to get a filtered list of Costs.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "cost_id": "cost-2ad052ed03d7",
        "usd_cost": 4.50528e-08,
        "original_currency": "USD",
        "original_cost": 4.50528e-08,
        "usage_quantity": 4.11e-07,
        "provider": "aws",
        "region_code": "ap-northeast-1",
        "product": "AWSDataTransfer",
        "account": "722069360300",
        "usage_type": "data-transfer.out",
        "tags": {},
        "additional_info": {
        "raw_usage_type": "APN1-DataTransfer-Out-Bytes"
        },
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "billed_at": "2021-01-01T00:00:00.000Z",
        "created_at": "2022-04-06T13:49:39.669Z"
        },
        {
        "cost_id": "cost-1d5e1b0dbf82",
        "usd_cost": 1.04e-05,
        "original_currency": "USD",
        "original_cost": 1.04e-05,
        "usage_quantity": 26.0,
        "provider": "aws",
        "region_code": "ap-northeast-1",
        "product": "AWSQueueService",
        "account": "722069360300",
        "tags": {},
        "additional_info": {
        "raw_usage_type": "APN1-Requests-Tier1"
        },
        "data_source_id": "ds-fcba92ca73b1",
        "domain_id": "domain-58010aa2e451",
        "billed_at": "2021-01-01T00:00:00.000Z",
        "created_at": "2022-04-06T13:49:39.675Z"
        }
        ],
        "total_count": 307066
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def analyze(self, request, context):
        """
        desc: Gets the Cost information of specific `product`s based on the time granularity: `DAILY`, `MONTHLY`, or `ACCUMULATED`. For `DAILY` granularity, this method can get the Cost data of at most 31 days. For `MONTHLY` or `ACCUMULATED` granularity, this method can get the Cost data of at most 12 months.
        request_example: >-
        {
        "granularity": "MONTHLY",
        "start": "2022-05",
        "end": "2022-07",
        "group_by": ["product"],
        "filter": [],
        "limit": 15,
        "include_others": true,
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "results": [
        {
        "product": "AmazonEC2",
        "total_usd_cost": 20962.3114306262,
        "usd_cost": {
        "2022-07": 4644.0801750137,
        "2022-05": 7984.6560889987995,
        "2022-06": 8333.5751666137
        }
        },
        {
        "usd_cost": {
        "2022-07": 2817.0,
        "2022-06": 5439.0,
        "2022-05": 5269.0
        },
        "total_usd_cost": 13525.0,
        "product": "AWS Marketplace"
        },
        {
        "product": "AmazonDocDB",
        "usd_cost": {
        "2022-05": 6910.6140347763,
        "2022-06": 3238.7851615211,
        "2022-07": 812.2452815070001
        },
        "total_usd_cost": 10961.6444778044
        }
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def invoices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def invoice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CostServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CreateCostRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.GetCostRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostsInfo.SerializeToString,
            ),
            'analyze': grpc.unary_unary_rpc_method_handler(
                    servicer.analyze,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'invoices': grpc.unary_unary_rpc_method_handler(
                    servicer.invoices,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'invoice': grpc.unary_unary_rpc_method_handler(
                    servicer.invoice,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.Cost', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Cost(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/create',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CreateCostRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/delete',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.GetCostRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def analyze(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/analyze',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def invoices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/invoices',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def invoice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.Cost/invoice',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__pb2.CostAnalyzeQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/statistics/plugin/storage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/statistics/plugin/storage.proto\x12\x1dspaceone.api.inventory.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"7\n\x0bInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"w\n\rVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12,\n\x0bsecret_data\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x9e\x01\n\rExportRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12,\n\x0bsecret_data\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\nPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\x8e\x02\n\x07Storage\x12_\n\x04init\x12*.spaceone.api.inventory.plugin.InitRequest\x1a).spaceone.api.inventory.plugin.PluginInfo\"\x00\x12P\n\x06verify\x12,.spaceone.api.inventory.plugin.VerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x06\x65xport\x12,.spaceone.api.inventory.plugin.ExportRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_INITREQUEST = DESCRIPTOR.message_types_by_name['InitRequest']
_VERIFYREQUEST = DESCRIPTOR.message_types_by_name['VerifyRequest']
_EXPORTREQUEST = DESCRIPTOR.message_types_by_name['ExportRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'spaceone.api.statistics.plugin.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYREQUEST,
  '__module__' : 'spaceone.api.statistics.plugin.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.VerifyRequest)
  })
_sym_db.RegisterMessage(VerifyRequest)

ExportRequest = _reflection.GeneratedProtocolMessageType('ExportRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTREQUEST,
  '__module__' : 'spaceone.api.statistics.plugin.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.ExportRequest)
  })
_sym_db.RegisterMessage(ExportRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.statistics.plugin.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.plugin.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_STORAGE = DESCRIPTOR.services_by_name['Storage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INITREQUEST._serialized_start=138
  _INITREQUEST._serialized_end=193
  _VERIFYREQUEST._serialized_start=195
  _VERIFYREQUEST._serialized_end=314
  _EXPORTREQUEST._serialized_start=317
  _EXPORTREQUEST._serialized_end=475
  _PLUGININFO._serialized_start=477
  _PLUGININFO._serialized_end=532
  _STORAGE._serialized_start=535
  _STORAGE._serialized_end=805
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import data_source_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2
from spaceone.api.cost_analysis.v1 import job_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2


class DataSourceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.register = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/register',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.RegisterDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/update',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.UpdateDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/update_plugin',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.UpdateDataSourcePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.verify_plugin = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/verify_plugin',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/enable',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/disable',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/deregister',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.sync = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/sync',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.SyncDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.GetDataSourceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourcesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.DataSource/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class DataSourceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def register(self, request, context):
        """
        desc: Registers a DataSource with information of the plugin to use. Information of the plugin includes `version`, `provider`, and `upgrade_mode`.
        request_example: >-
        {
        "name": "AWS HyperBilling Data Source test",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "conditions_policy": "ALWAYS",
        "options": {
        "stop_processing": true
        },
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        },
        "conditions": [],
        "tags": {},
        "name": "match_service_account"
        }
        ]
        },
        "secret_id": "secret-ca134639483",
        "upgrade_mode": "AUTO"
        },
        "tags": {"a": "b"}
        }
        response_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "name": "AWS HyperBilling Data Source test",
        "state": "ENABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "options": {
        "stop_processing": true
        },
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        },
        "domain_id": "domain-58010aa2e451",
        "conditions": [],
        "name": "match_service_account",
        "tags": {},
        "data_source_id": "ds-085d1e872789",
        "conditions_policy": "ALWAYS"
        }
        ]
        },
        "secret_id": "secret-ca134639483",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "a": "b"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:58:36.080Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific DataSource. You can make changes in DataSource settings, including `name` and `tags`.
        request_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "name": "AWS HyperBilling Data Source test2",
        "tags": {
        "type": "test"
        }
        }
        response_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "name": "AWS HyperBilling Data Source test2",
        "state": "ENABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "tags": {},
        "name": "match_service_account",
        "conditions_policy": "ALWAYS",
        "actions": {
        "match_service_account": {
        "target": "data.account_id",
        "source": "account"
        }
        },
        "options": {
        "stop_processing": true
        },
        "conditions": []
        }
        ]
        },
        "secret_id": "secret-dca385e85a27",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "type": "test"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:58:36.080Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """
        desc: Updates the plugin of a specific DataSource. This method resets the plugin data in the DataSource to update the `metadata`.
        request_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "version": "1.0.4",
        "options": {},
        "upgrade_mode": "AUTO"
        }
        response_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "name": "AWS HyperBilling Data Source test2",
        "state": "DISABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "tags": {},
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        },
        "options": {
        "stop_processing": true
        },
        "conditions_policy": "ALWAYS",
        "name": "match_service_account",
        "conditions": []
        }
        ]
        },
        "secret_id": "secret-dca385e85a27",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "type": "test"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:58:36.080Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify_plugin(self, request, context):
        """
        desc: Verifies the plugin of a specific DataSource. This method validates the plugin data, `version` and `endpoint`.
        request_example: >-
        {
        "data_source_id": "ds-085d1e872789"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific DataSource. By enabling a DataSource, you can communicate with an external cloud service via the plugin.
        request_example: >-
        {
        "data_source_id": "ds-085d1e872789"
        }
        response_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "name": "AWS HyperBilling Data Source test2",
        "state": "ENABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "actions": {
        "match_service_account": {
        "target": "data.account_id",
        "source": "account"
        }
        },
        "conditions_policy": "ALWAYS",
        "conditions": [],
        "options": {
        "stop_processing": true
        },
        "name": "match_service_account",
        "tags": {}
        }
        ]
        },
        "secret_id": "secret-dca385e85a27",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "type": "test"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:58:36.080Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific DataSource. By disabling a DataSource, you can block communication with an external cloud service via the plugin.
        request_example: >-
        {
        "data_source_id": "ds-085d1e872789"
        }
        response_example: >-
        {
        "data_source_id": "ds-085d1e872789",
        "name": "AWS HyperBilling Data Source test2",
        "state": "DISABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "name": "match_service_account",
        "options": {
        "stop_processing": true
        },
        "conditions_policy": "ALWAYS",
        "conditions": [],
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        },
        "tags": {}
        }
        ]
        },
        "secret_id": "secret-dca385e85a27",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "type": "test"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T10:58:36.080Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """
        desc: Deregisters and deletes a specific DataSource. You must specify the `data_source_id` of the DataSource to deregister.
        request_example: >-
        {
        "data_source_id": "ds-085d1e872789"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def sync(self, request, context):
        """
        desc: Manually runs a specific DataSource to collect the cost data. This method is to get up-to-date cost data.
        request_example: >-
        {
        "data_source_id": "ds-c96609f5afeb"
        }
        response_example: >-
        {
        "job_id": "job-ba2598167785",
        "status": "IN_PROGRESS",
        "options": {
        "no_preload_cache": false,
        "start": null
        },
        "total_tasks": 1,
        "remained_tasks": 1,
        "data_source_id": "ds-c96609f5afeb",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T11:16:59.923Z",
        "updated_at": "2022-07-19T11:16:59.923Z",
        "changed": [
        {
        "start": "2022-07-01T00:00:00.000Z"
        }
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific DataSource. Prints detailed information about the DataSource, including `name`, `state`, and `plugin_info`.
        request_example: >-
        {
        "data_source_id": "ds-fcba92ca73b1"
        }
        response_example: >-
        {
        "data_source_id": "ds-fcba92ca73b1",
        "name": "AWS HyperBilling Data Source",
        "state": "ENABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "conditions_policy": "ALWAYS",
        "options": {
        "stop_processing": true
        },
        "tags": {},
        "conditions": [],
        "name": "match_service_account",
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        }
        }
        ]
        },
        "secret_id": "secret-dca385e85a27",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "a": "b"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-30T02:21:28.756Z",
        "last_synchronized_at": "2022-07-17T16:00:05.077Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all DataSources. You can use a query to get a filtered list of DataSources.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "data_source_id": "ds-fcba92ca73b1",
        "name": "AWS HyperBilling Data Source",
        "state": "ENABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "version": "1.0.4",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "name": "match_service_account",
        "conditions": [],
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.account_id"
        }
        },
        "conditions_policy": "ALWAYS",
        "tags": {},
        "options": {
        "stop_processing": true
        }
        }
        ]
        },
        "secret_id": "secret-dca385e85a27",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {
        "a": "b"
        },
        "cost_tag_keys": [
        "Name",
        "Environment",
        "Role",
        "Service"
        ],
        "cost_additional_info_keys": [
        "raw_usage_type"
        ],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-30T02:21:28.756Z",
        "last_synchronized_at": "2022-07-17T16:00:05.077Z"
        },
        {
        "data_source_id": "ds-c96609f5afeb",
        "name": "MZC HyperBilling Data Source",
        "state": "ENABLED",
        "data_source_type": "EXTERNAL",
        "plugin_info": {
        "plugin_id": "plugin-mzc-hyperbilling-cost-datasource",
        "version": "1.0.3",
        "options": {},
        "metadata": {
        "data_source_rules": [
        {
        "conditions": [],
        "options": {
        "stop_processing": true
        },
        "conditions_policy": "ALWAYS",
        "name": "match_service_account",
        "tags": {},
        "actions": {
        "match_service_account": {
        "source": "account",
        "target": "data.project_id"
        }
        }
        }
        ]
        },
        "secret_id": "secret-354d142229e5",
        "upgrade_mode": "AUTO"
        },
        "template": {},
        "tags": {},
        "cost_tag_keys": [],
        "cost_additional_info_keys": [],
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-13T05:34:54.223Z",
        "last_synchronized_at": "2022-07-17T16:00:08.254Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.RegisterDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.UpdateDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.UpdateDataSourcePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'verify_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.verify_plugin,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'sync': grpc.unary_unary_rpc_method_handler(
                    servicer.sync,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.SyncDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.GetDataSourceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourcesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.DataSource', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSource(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/register',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.RegisterDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/update',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.UpdateDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/update_plugin',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.UpdateDataSourcePluginRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/verify_plugin',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/enable',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/disable',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/deregister',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def sync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/sync',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.SyncDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.GetDataSourceRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourcesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.DataSource/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_data__source__pb2.DataSourceStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/dashboard/v1/custom_widget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/dashboard/v1/custom_widget.proto\x12\x19spaceone.api.dashboard.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x88\x02\n\x19\x43reateCustomWidgetRequest\x12\x13\n\x0bwidget_name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12/\n\x0ewidget_options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0finherit_options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\x8d\x02\n\x19UpdateCustomWidgetRequest\x12\x18\n\x10\x63ustom_widget_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12/\n\x0ewidget_options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0finherit_options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"B\n\x13\x43ustomWidgetRequest\x12\x18\n\x10\x63ustom_widget_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x16GetCustomWidgetRequest\x12\x18\n\x10\x63ustom_widget_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa1\x01\n\x11\x43ustomWidgetQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63ustom_widget_id\x18\x02 \x01(\t\x12\x13\n\x0bwidget_name\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xe3\x02\n\x10\x43ustomWidgetInfo\x12\x18\n\x10\x63ustom_widget_id\x18\x01 \x01(\t\x12\x13\n\x0bwidget_name\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12/\n\x0ewidget_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0finherit_options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x14 \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\x12\x12\n\nupdated_at\x18\x17 \x01(\t\"f\n\x11\x43ustomWidgetsInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.dashboard.v1.CustomWidgetInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15\x43ustomWidgetStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa3\x07\n\x0c\x43ustomWidget\x12\x91\x01\n\x06\x63reate\x12\x34.spaceone.api.dashboard.v1.CreateCustomWidgetRequest\x1a+.spaceone.api.dashboard.v1.CustomWidgetInfo\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/dashboard/v1/custom-widgets\x12\xa3\x01\n\x06update\x12\x34.spaceone.api.dashboard.v1.UpdateCustomWidgetRequest\x1a+.spaceone.api.dashboard.v1.CustomWidgetInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./dashboard/v1/custom-widget/{custom_widget_id}\x12\x88\x01\n\x06\x64\x65lete\x12..spaceone.api.dashboard.v1.CustomWidgetRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30*./dashboard/v1/custom-widget/{custom_widget_id}\x12\x9d\x01\n\x03get\x12\x31.spaceone.api.dashboard.v1.GetCustomWidgetRequest\x1a+.spaceone.api.dashboard.v1.CustomWidgetInfo\"6\x82\xd3\xe4\x93\x02\x30\x12./dashboard/v1/custom-widget/{custom_widget_id}\x12\xaf\x01\n\x04list\x12,.spaceone.api.dashboard.v1.CustomWidgetQuery\x1a,.spaceone.api.dashboard.v1.CustomWidgetsInfo\"K\x82\xd3\xe4\x93\x02\x45\x12\x1c/dashboard/v1/custom-widgetsZ%\"#/dashboard/v1/custom-widgets/search\x12|\n\x04stat\x12\x30.spaceone.api.dashboard.v1.CustomWidgetStatQuery\x1a\x17.google.protobuf.Struct\")\x82\xd3\xe4\x93\x02#\"!/dashboard/v1/custom-widgets/statb\x06proto3')



_CREATECUSTOMWIDGETREQUEST = DESCRIPTOR.message_types_by_name['CreateCustomWidgetRequest']
_UPDATECUSTOMWIDGETREQUEST = DESCRIPTOR.message_types_by_name['UpdateCustomWidgetRequest']
_CUSTOMWIDGETREQUEST = DESCRIPTOR.message_types_by_name['CustomWidgetRequest']
_GETCUSTOMWIDGETREQUEST = DESCRIPTOR.message_types_by_name['GetCustomWidgetRequest']
_CUSTOMWIDGETQUERY = DESCRIPTOR.message_types_by_name['CustomWidgetQuery']
_CUSTOMWIDGETINFO = DESCRIPTOR.message_types_by_name['CustomWidgetInfo']
_CUSTOMWIDGETSINFO = DESCRIPTOR.message_types_by_name['CustomWidgetsInfo']
_CUSTOMWIDGETSTATQUERY = DESCRIPTOR.message_types_by_name['CustomWidgetStatQuery']
CreateCustomWidgetRequest = _reflection.GeneratedProtocolMessageType('CreateCustomWidgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECUSTOMWIDGETREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CreateCustomWidgetRequest)
  })
_sym_db.RegisterMessage(CreateCustomWidgetRequest)

UpdateCustomWidgetRequest = _reflection.GeneratedProtocolMessageType('UpdateCustomWidgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECUSTOMWIDGETREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.UpdateCustomWidgetRequest)
  })
_sym_db.RegisterMessage(UpdateCustomWidgetRequest)

CustomWidgetRequest = _reflection.GeneratedProtocolMessageType('CustomWidgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMWIDGETREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CustomWidgetRequest)
  })
_sym_db.RegisterMessage(CustomWidgetRequest)

GetCustomWidgetRequest = _reflection.GeneratedProtocolMessageType('GetCustomWidgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCUSTOMWIDGETREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetCustomWidgetRequest)
  })
_sym_db.RegisterMessage(GetCustomWidgetRequest)

CustomWidgetQuery = _reflection.GeneratedProtocolMessageType('CustomWidgetQuery', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMWIDGETQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CustomWidgetQuery)
  })
_sym_db.RegisterMessage(CustomWidgetQuery)

CustomWidgetInfo = _reflection.GeneratedProtocolMessageType('CustomWidgetInfo', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMWIDGETINFO,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CustomWidgetInfo)
  })
_sym_db.RegisterMessage(CustomWidgetInfo)

CustomWidgetsInfo = _reflection.GeneratedProtocolMessageType('CustomWidgetsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMWIDGETSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CustomWidgetsInfo)
  })
_sym_db.RegisterMessage(CustomWidgetsInfo)

CustomWidgetStatQuery = _reflection.GeneratedProtocolMessageType('CustomWidgetStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMWIDGETSTATQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.custom_widget_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CustomWidgetStatQuery)
  })
_sym_db.RegisterMessage(CustomWidgetStatQuery)

_CUSTOMWIDGET = DESCRIPTOR.services_by_name['CustomWidget']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CUSTOMWIDGET.methods_by_name['create']._options = None
  _CUSTOMWIDGET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\036\"\034/dashboard/v1/custom-widgets'
  _CUSTOMWIDGET.methods_by_name['update']._options = None
  _CUSTOMWIDGET.methods_by_name['update']._serialized_options = b'\202\323\344\223\0020\032./dashboard/v1/custom-widget/{custom_widget_id}'
  _CUSTOMWIDGET.methods_by_name['delete']._options = None
  _CUSTOMWIDGET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0020*./dashboard/v1/custom-widget/{custom_widget_id}'
  _CUSTOMWIDGET.methods_by_name['get']._options = None
  _CUSTOMWIDGET.methods_by_name['get']._serialized_options = b'\202\323\344\223\0020\022./dashboard/v1/custom-widget/{custom_widget_id}'
  _CUSTOMWIDGET.methods_by_name['list']._options = None
  _CUSTOMWIDGET.methods_by_name['list']._serialized_options = b'\202\323\344\223\002E\022\034/dashboard/v1/custom-widgetsZ%\"#/dashboard/v1/custom-widgets/search'
  _CUSTOMWIDGET.methods_by_name['stat']._options = None
  _CUSTOMWIDGET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002#\"!/dashboard/v1/custom-widgets/stat'
  _CREATECUSTOMWIDGETREQUEST._serialized_start=200
  _CREATECUSTOMWIDGETREQUEST._serialized_end=464
  _UPDATECUSTOMWIDGETREQUEST._serialized_start=467
  _UPDATECUSTOMWIDGETREQUEST._serialized_end=736
  _CUSTOMWIDGETREQUEST._serialized_start=738
  _CUSTOMWIDGETREQUEST._serialized_end=804
  _GETCUSTOMWIDGETREQUEST._serialized_start=806
  _GETCUSTOMWIDGETREQUEST._serialized_end=889
  _CUSTOMWIDGETQUERY._serialized_start=892
  _CUSTOMWIDGETQUERY._serialized_end=1053
  _CUSTOMWIDGETINFO._serialized_start=1056
  _CUSTOMWIDGETINFO._serialized_end=1411
  _CUSTOMWIDGETSINFO._serialized_start=1413
  _CUSTOMWIDGETSINFO._serialized_end=1515
  _CUSTOMWIDGETSTATQUERY._serialized_start=1517
  _CUSTOMWIDGETSTATQUERY._serialized_end=1613
  _CUSTOMWIDGET._serialized_start=1616
  _CUSTOMWIDGET._serialized_end=2547
# @@protoc_insertion_point(module_scope)
